<?php
// v3.42
// PJC 04-10-2018 remove disk space from vmap
// PJC 13-04-2018 nice
// PJC 30-05-2017 web-wav & ftp-wav wrong way round.
// PJC 25-01-2017 removed $IP
// PJC 17-01-2017 Download links updated
// PJC 15-06-2016 Updated PCS Files & System Backup to include /SpliceCom/ftp/tftp/*.site
// PJC 23-09-2014 Links updated
// PJC 24-01-2014 System Database Backup Link Corrected
// PJC AUG 2013
$page_id = "051";
include ".access.php";
include "tzone.php"; // include timezone

$script=$_SERVER['SCRIPT_NAME'];
$action = (isset($_REQUEST['action'])) ? $_REQUEST['action'] : "";
$mode = (isset ($_REQUEST['mode'] )) ? $_REQUEST['mode'] : NULL;
?>

<html>
<head>
<title>System Backups - Web, Wav And Greeting Backups</title>
<META HTTP-EQUIV="Expires" CONTENT="-1">
<META HTTP-EQUIV="Pragma" CONTENT="no-cache">
<META HTTP-EQUIV="Cache-Control" CONTENT="no-cache">
<meta http-equiv="Content-type" content="text/html; charset=UTF-8"/>
<link href="css/Styles.css" rel="stylesheet" type="text/css">
<script src="js/wiz/jquery-1.8.0.js" type="text/javascript"></script>
<script src="js/wiz/jquery.validate.js" type="text/javascript"></script>
<script src="js/wiz/main.js" type="text/javascript"></script>
<script src="js/wiz/extra.js" type="text/javascript"></script>

<script language="javascript" src="js/progress.js"></script>
<script type="text/javascript">
	function formSubmit(str)
		{
		document.getElementById(str).submit();
		}
</script>
<script language="javascript">
var popupWindow = null;
function centeredPopup(url,winName,w,h,scroll){
LeftPosition = (screen.width) ? (screen.width-w)/2 : 0;
TopPosition = (screen.height) ? (screen.height-h)/2 : 0;
settings =
'height='+h+',width='+w+',top='+TopPosition+',left='+LeftPosition+',scrollbars='+scroll+',resizable'
popupWindow = window.open(url,winName,settings)
}
</script>
</head>
<body>

<div style="position:absolute; top:8px; right:8px" >
<img onClick="window.location = '<?php echo $script;?>'" src="images/refresh16.gif" alt="refresh" title="refresh" border="0">&nbsp;&nbsp;
<img onClick="centeredPopup('help/help_systembackup.php','help','600','500','yes');return false" src="images/help16.gif" alt="help" title="help" border="0">&nbsp;&nbsp;
<img onClick="window.location = 'assist.php'" src="images/assist16.gif" alt="manager assist" title="manager assist" border="0">&nbsp;&nbsp;
<img onClick="window.location = 'index.php'" src="images/home16.gif" alt="home" title="home" border="0">
</div>
<div id="contain">
<h2><img src='images/backup.png' style="vertical-align:middle;">&nbsp;System Backups - Web, Wav And Greeting Backups</h2>
This script allows you to perform various types of backups on your CallServer.<br/>

For details on how to restore these backup files - <a href="#" class="show_hide">Click Here</a><br/>

<div class="slidingDiv" hidden>
<b>Restore Backup Files</b><br/>
Restoring backup files WILL overwrite files on the CallServer/SoftPBX<br/>
Tar files will need to be ftp uploaded and then moved to the correct location<br/><br/>
<strong>Rebooting</strong><br/>
For a CallServer you can reboot in the normal manner<br/>
For a SoftPBX the following command can be used : sudo /etc/init.d/adminmodule restart<br/><br/>
<strong>Database Backup</strong><br/>
Extract the backup from the tar file and either restore in the normal manner or via the uploadconfig script<br/><br/>
<strong>Greetings Backup</strong><br/>
Upload the greetings.tar from the backup and move to /SpliceCom/Mailbox/<br/>
Using telnet/ssh goto /SpliceCom/Mailbox and restore the greetings using: tar -xvf greetings.tar<br/><br/>
<strong>PCS Files Backup</strong><br/>
<i>/SpliceCom/pcs5xx</i><br/>Upload the splicecom-pcs5xx.tar from the backup and move to /SpliceCom/<br/>
Using telnet/ssh goto /SpliceCom and restore the ringtunes and logos using: tar -xvf splicecom-pcs5xx.tar<br/><br/>
<i>/SpliceCom/Web/download</i><br/>Upload the web-pcs5xx.tar from the backup and move to /SpliceCom/Web/download/<br/>
Using telnet/ssh goto /SpliceCom/Web/download and restore the ringtunes and logos using: tar -xvf web-pcs5xx.tar<br/><br/>
<strong>System Backup</strong><br/>
<i>Database Backup</i><br/>Extract the backup from the tar file and either restore in the normal manner or via the uploadconfig script<br/><br/>
<i>Voicemail</i><br/>Upload the voicemail.tar0 from the backup and move to /SpliceCom/ftp/<br/>
Rename the file to voicemail.tar using : mv voicemail.tar0 voicemail.tar<br/>
Reboot the CallServer for the voicemail to be restored<br/><br/>
<i>Web</i><br/>Upload the web.tar from the backup and move to /SpliceCom/Web/<br/>
Using telnet/ssh goto /SpliceCom/web and restore the Web and logos using: tar -xvf web.tar<br/><br/>
<strong>Voicemail Backup</strong><br/>
Upload the BackupVoicemailFiles.tar and move to /SpliceCom/Mailbox/<br/>
Using telnet/ssh goto /SpliceCom/Mailbox and restore the voicemail using: tar -xvf BackupVoicemailFiles.tar<br/><br/>
<strong>WAV Files Backup</strong><br/>
<i>/SpliceCom/ftp</i><br/>Upload the ftp-wav.tar from the backup and move to /SpliceCom/ftp/<br/>
Using telnet/ssh goto /SpliceCom/ftp and restore the ringtunes and logos using: tar -xvf ftp-wav.tar<br/><br/>
<i>/SpliceCom/Web</i><br/>Upload the web-wav.tar from the backup and move to /SpliceCom/Web/<br/>
Using telnet/ssh goto /SpliceCom/Web/ and restore the ringtunes and logos using: tar -xvf web-wav.tar<br/><br/>
<div align="right"><a href="#" class="show_hide">HIDE</a></div>
</div>



<h3>System Backups</h3>
Select the type of backup to be created. Once completed you can download this file via your browser.<br/>
<?php
if (! file_exists("/SpliceCom/install/assets/vmap")) {
    $bytes = disk_free_space(".");
    $si_prefix = array( 'B', 'KB', 'MB', 'GB', 'TB', 'EB', 'ZB', 'YB' );
    $base = 1024; $class = min((int)log($bytes , $base) , count($si_prefix) - 1);
    echo "Current Disk Free Space : <b>".sprintf('%1.2f' , $bytes / pow($base,$class)) . ' ' . $si_prefix[$class] . '</b><br/><br/>';
}
?>
<table border="0">
   <tr><td><b>Database Backup</b></td><td>A normal LDAP Database backup</td></tr>
   <tr><td><b>Greetings Backup</b></td><td>A backup of all files containing the word Greeting in /SpliceCom/Mailbox and subfolders</td></tr>
   <tr><td><b>PCS Files Backup</b></td><td>A backup of all PCS ringtunes and logo files from either /SpliceCom/pcs5xx and/or /SpliceCom/Web/download/pcs5xx</td></tr>
   <tr><td><b>System Backup</b></td><td>A complete backup of the /Web & /voicemail folders, PCS5xx files, WAV Files from /ftp and includes a Database backup - excludes Archive, aatmp and aadropbox</td></tr>
   <tr><td><b>Voicemail Backup</b></td><td>A backup of all voicemail messages and greetings in /SpliceCom/Mailbox - excludes Archive, aatmp and aadropbox</td></tr>
   <tr><td><b>Wav Files Backup</b></td><td>A backup of WAV files in the /ftp and /Web folders.</td></tr>
</table>


<form id="frm1" method="post" action="<?php echo $_SERVER['PHP_SELF']?>">
<br>Select Backup : <select name="action" onchange="formSubmit('frm1')">
<option></option>
<option value='1' <?php if ($action == '1') echo 'selected'; ?> >Database Backup</option>
<option value='3' <?php if ($action == '3') echo 'selected'; ?> >Greetings Backup</option>
<option value='5' <?php if ($action == '5') echo 'selected'; ?> >PCS Files Backup</option>
<option value='2' <?php if ($action == '2') echo 'selected'; ?> >System Backup</option>
<option value='6' <?php if ($action == '6') echo 'selected'; ?> >Voicemail Backup</option>
<option value='4' <?php if ($action == '4') echo 'selected'; ?> >WAV Files Backup</option>

</select>&nbsp;<input type='hidden' name='mode' value='1'><a href='#' class="tooltip" title="Select The Type Of Backup To Be Performed"><img src="images/tooltip.jpg"></a></form>

<?php
If (isset($_REQUEST['action']) && $_REQUEST['action']>='1') {
start(""); show(""); exec("cd /SpliceCom/Web/download; rm *.tar;");
$ds=ldap_connect("127.0.0.1",4000); $r=ldap_bind($ds,"INTERNAL","0123456");
$sr = ldap_read($ds,"cn=System","objectclass=*"); $info = ldap_get_entries($ds,$sr);
$sysname=str_replace(' ','',(substr($info[0]['administrationdomain'][0],0,10))); $backup = $sysname."-Backup-".date('d.m.y-His');
}

//System Database Backup
if (isset($_REQUEST['action']) && $_REQUEST['action'] == '1') {
show("Backup system database");
$ent["dobackupto"] = "../Web/download/$backup.txt";  ldap_modify($ds,"cn=Commands",$ent); ldap_close($ds);
show("System database backup completed<br/>");
$fs = (filesize("/SpliceCom/Database.txt"));
sleep(ceil(($fs/(1024 * 1024))));
$filename = $sysname."-BackupDatabase-".date('d.m.y-His');
exec("cd /SpliceCom/Web/download/; nice -10 tar -cvf $filename.tar $backup.txt; rm $backup.txt;");
stop("<b>Done</b>...<br/><br/><a href='download.php?download=/SpliceCom/Web/download/$filename.tar'><img src='images/down.png' alt='Download Backup' title='Download Backup' width='50' height='50'><br/>Download</a>");
}

// System Backup - Database, Web & Voicemail
if (isset($_REQUEST['action']) && $_REQUEST['action'] == '2') { 
$pcs_files ='';
show("Backup system database");
$ent["dobackupto"] = "../Web/download/$backup.txt";  ldap_modify($ds,"cn=Commands",$ent); ldap_close($ds);
$fs = (filesize("/SpliceCom/Database.txt"));
sleep(ceil(($fs/(1024 * 1024))));
show("Database backup completed");
show("<b>Done</b><br/>");

show("Changing to /SpliceCom/Web<br/>Backing up /Web");
exec('cd /SpliceCom/Web; nice -10 tar -cvf /tmp/web.tar *; mv /tmp/web.tar /SpliceCom/Web/download/');
show("Web backup completed");
show("<b>Done</b><br/>");

show("Changing to /SpliceCom/Mailbox<br/>Backing up /SpliceCom/Mailbox");
exec('cd /SpliceCom/; nice -10 tar --exclude=Archive --exclude=aadropbox --exclude=aatmp -cvhf /SpliceCom/Web/download/voicemail.tar0 Mailbox');
show("Voicemail backup completed");
show("<b>Done</b><br/>");

show("Changing to /SpliceCom/ftp<br/>Backing up WAV Files<br/>");
exec("cd /SpliceCom/ftp/; find * -name '*.wav' | nice -10 tar -cvPf /SpliceCom/Web/download/ftp-wav.tar -T -");

$site_files = array("pcs54x-256M.site","pcs5xx-256M.site","pcs5x1-256M.site","pcs5x3-256M.site");
$site_state = 0;
foreach ($site_files as $site) {
	if(file_exists("/SpliceCom/ftp/tftp/$site")) $site_state++;
}

if (file_exists("/SpliceCom/pcs5xx") && file_exists("/SpliceCom/Web/download/pcs5xx")) {
	show("Changing to /SpliceCom/pcs5xx<br/>Backing up PCS Site Files<br/>");
	exec("cd /SpliceCom/; nice -10 tar -cvf /SpliceCom/Web/download/splicecom-pcs5xx.tar pcs5xx/*");
	show("Changing to /SpliceCom/Web/download/pcs5xx<br/>Backing up PCS Site Files");
	exec("cd /SpliceCom/Web/download/; nice -10 tar -cvf /SpliceCom/Web/download/web-pcs5xx.tar pcs5xx/*");
	if ($site_state >0) {
			show("Changing to /SpliceCom/ftp/tftp/<br/>Backing up PCS Site Files<br/>");
			exec("cd /SpliceCom/ftp/tftp/; nice -10 tar -cvf /SpliceCom/Web/download/site-pcs5xx.tar *.site;");
		}
	$pcs_files .= "splicecom-pcs5xx.tar web-pcs5xx.tar site-pcs5xx.tar";
	show("Moving backup files");
	show("<b>Done</b><br/>");
}elseif (file_exists("/SpliceCom/pcs5xx")) {
	show("Changing to /SpliceCom/pcs5xx<br/>Backing up PCS Site Files");
	exec("cd /SpliceCom/; nice -10 tar -cvf /SpliceCom/Web/download/splicecom-pcs5xx.tar pcs5xx/*");
	if ($site_state >0) {
			show("Changing to /SpliceCom/ftp/tftp/<br/>Backing up PCS Site Files<br/>");
			exec("cd /SpliceCom/ftp/tftp/; nice -10 tar -cvf /SpliceCom/Web/download/site-pcs5xx.tar *.site;");
		}
	$pcs_files .= "splicecom-pcs5xx.tar site-pcs5xx.tar";
	show("Moving backup files<br/><b>Done</b><br/>");
}elseif (file_exists("/SpliceCom/Web/download/pcs5xx")) {
	show("Changing to /SpliceCom/Web/download/pcs5xx<br/>Backing up PCS Site Files");
	exec("cd /SpliceCom/Web/download/; nice -10 tar -cvf /SpliceCom/Web/download/web-pcs5xx.tar pcs5xx/*");
	if ($site_state >0) {
			show("Changing to /SpliceCom/ftp/tftp/<br/>Backing up PCS Site Files<br/>");
			exec("cd /SpliceCom/ftp/tftp/; nice -10 tar -cvf /SpliceCom/Web/download/site-pcs5xx.tar *.site;");
		}
	$pcs_files .= "web-pcs5xx.tar site-pcs5xx.tar";
	show("Moving backup files<br/><b>Done</b><br/>");
}elseif ($site_state >0) {
			show("Changing to /SpliceCom/ftp/tftp/<br/>Backing up PCS Site Files<br/>");
			exec("cd /SpliceCom/ftp/tftp/; nice -10 tar -cvf /SpliceCom/Web/download/site-pcs5xx.tar *.site;");
			$pcs_files .= "site-pcs5xx.tar";
	}

show("Moving files and compressing");
$filename = $sysname."-BackupSystem-".date('d.m.y-His');
exec("cd /SpliceCom/Web/download; nice -10 tar -cvf $filename.tar $backup.txt ftp-wav.tar web.tar voicemail.tar0 $pcs_files; nice -10 gzip $filename.tar; rm ftp-wav.tar; rm $backup.txt; rm web.tar; rm voicemail.tar0; rm $pcs_files");
if (file_exists("/SpliceCom/Web/download/{$filename}.tar.gz")) {
stop("<b>Done</b>...<br/><br/><a href='download.php?download=/SpliceCom/Web/download/$filename.tar.gz'><img src='images/down.png' alt='Download Backup' title='Download Backup' width='50' height='50'><br/>Download</a>");
} else {
stop("<b>Done</b>...<br/><br/>No Backup file Created. Check The Items Exist On The CallServer / SoftPBX");
}
}

// voicemail greetings
if (isset($_REQUEST['action']) && $_REQUEST['action'] == '3') {
$backup = $sysname."-BackupGreetings-".date('d.m.y-His').".tar";
show("Changing to /SpliceCom/Mailbox<br/>Backing up Greetings");
exec("cd /SpliceCom/Mailbox; find * -name '*Greeting*' | nice -10 tar -cvf /SpliceCom/Web/download/greetings.tar -T -");
show("Greetings backup completed<br/>");
show("Moving files and compressing<br/>");
exec("cd /SpliceCom/Web/download/; nice -10 tar -cvf $backup greetings.tar; rm greetings.tar");
stop("<b>Done</b>...<br/><br/><a href='download.php?download=/SpliceCom/Web/download/$backup'><img src='images/down.png' alt='Download Backup' title='Download Backup' width='50' height='50'><br/>Download</a>");
}

//WAV files
if (isset($_REQUEST['action']) && $_REQUEST['action'] == '4') {
$backup = $sysname."-BackupWavs-".date('d.m.y-His').".tar";
show("Changing to /SpliceCom/ftp<br/>Backing up WAV Files<br/>");
exec("cd /SpliceCom/ftp/; find * -name '*.wav' | nice -10 tar -cvPf /SpliceCom/Web/download/ftp-wav.tar -T -");
show("Changing to /SpliceCom/Web<br/>Backing up WAV Files<br/>");
exec("cd /SpliceCom/Web/; find * -name '*.wav' | nice -10 tar -cvPf /SpliceCom/Web/download/web-wav.tar -T -");
show("WAV Files backup completed");
show("Moving files and compressing<br/>");
exec("cd /SpliceCom/Web/download/; nice -10 tar -cvf $backup web-wav.tar ftp-wav.tar; rm web-wav.tar; rm ftp-wav.tar");

if (file_exists("/SpliceCom/Web/download/$backup")) {
stop("<b>Done</b>...<br/><br/><a href='download.php?download=/SpliceCom/Web/download/$backup'><img src='images/down.png' alt='Download Backup' title='Download Backup' width='50' height='50'><br/>Download</a>");
} else {
stop("<b>Done</b>...<br/><br/>No Backup file Created. Check The Items Exist On The CallServer / SoftPBX");
}
	}

//Voicemail files
if (isset($_REQUEST['action']) && $_REQUEST['action'] == '6') {
$backup = $sysname."-BackupVoicemails-".date('d.m.y-His').".tar";
show("Changing to /SpliceCom/Mailbox<br/>Backing up voicemails<br/>");
exec("cd /SpliceCom/; nice -10 tar --exclude=Archive --exclude=aadropbox --exclude=aatmp -cvhf /SpliceCom/Web/download/$backup Mailbox");
show("Moving files and compressing<br/>");
if (file_exists("/SpliceCom/Web/download/$backup")) {
stop("<b>Done</b>...<br/><br/><a href='download.php?download=/SpliceCom/Web/download/$backup'><img src='images/down.png' alt='Download Backup' title='Download Backup' width='50' height='50'><br/>Download</a>");
} else {
stop("<b>Done</b>...<br/><br/>No Backup file Created. Check The Items Exist On The CallServer / SoftPBX");
}
}


//PCS Site files
if (isset($_REQUEST['action']) && $_REQUEST['action'] == '5') {
$backup = $sysname."-BackupPCSSite-".date('d.m.y-His').".tar";
$site_files = array("pcs54x-256M.site","pcs5xx-256M.site","pcs5x1-256M.site","pcs5x3-256M.site");
$site_state = 0;
foreach ($site_files as $site) {
	if(file_exists("/SpliceCom/ftp/tftp/$site")) $site_state++;
}

if (file_exists("/SpliceCom/pcs5xx") && file_exists("/SpliceCom/Web/download/pcs5xx")) {
		show("Changing to /SpliceCom/pcs5xx<br/>Backing up PCS Site Files<br/>");
		exec("cd /SpliceCom/; nice -10 tar -cvf /SpliceCom/Web/download/splicecom-pcs5xx.tar pcs5xx/*");
		show("Changing to /SpliceCom/Web/download/pcs5xx<br/>Backing up PCS Site Files<br/>");
		exec("cd /SpliceCom/Web/download/; nice -10 tar -cvf /SpliceCom/Web/download/web-pcs5xx.tar pcs5xx/*;");
		if ($site_state >0) {
			show("Changing to /SpliceCom/ftp/tftp/<br/>Backing up PCS Site Files<br/>");
			exec("cd /SpliceCom/ftp/tftp/; nice -10 tar -cvf /SpliceCom/Web/download/site-pcs5xx.tar *.site;");
		}
		show("Moving files and compressing<br/>");
		exec("cd /SpliceCom/Web/download/; nice -10 tar -cvf $backup splicecom-pcs5xx.tar web-pcs5xx.tar site-pcs5xx.tar; rm web-pcs5xx.tar; rm splicecom-pcs5xx.tar; rm site-pcs5xx.tar");
	}elseif (file_exists("/SpliceCom/pcs5xx")) {
		show("Changing to /SpliceCom/pcs5xx<br/>Backing up PCS Site Files<br/>");
		exec("cd /SpliceCom/; nice -10 tar -cvf /SpliceCom/Web/download/splicecom-pcs5xx.tar pcs5xx/*");
		if ($site_state >0) {
			show("Changing to /SpliceCom/ftp/tftp/<br/>Backing up PCS Site Files<br/>");
			exec("cd /SpliceCom/ftp/tftp/; nice -10 tar -cvf /SpliceCom/Web/download/site-pcs5xx.tar *.site;");
		}
		show("Moving files and compressing<br/>");
		exec("cd /SpliceCom/Web/download/; nice -10 tar -cvf $backup splicecom-pcs5xx.tar site-pcs5xx.tar; rm splicecom-pcs5xx.tar; rm site-pcs5xx.tar;");
	}elseif (file_exists("/SpliceCom/Web/download/pcs5xx")) {
		show("Changing to /SpliceCom/Web/download/pcs5xx<br/>Backing up PCS Site Files<br/>");
		exec("cd /SpliceCom/Web/download/; nice -10 tar -cvf /SpliceCom/Web/download/web-pcs5xx.tar pcs5xx/*");
		if ($site_state >0) {
			show("Changing to /SpliceCom/ftp/tftp/<br/>Backing up PCS Site Files<br/>");
			exec("cd /SpliceCom/ftp/tftp/; nice -10 tar -cvf /SpliceCom/Web/download/site-pcs5xx.tar *.site;");
		}
		show("Moving files and compressing<br/>");
		exec("cd /SpliceCom/Web/download/; nice -10 tar -cvf $backup web-pcs5xx.tar site-pcs5xx.tar; rm web-pcs5xx.tar; rm site-pcs5xx.tar;");
	}elseif ($site_state >0) {
			show("Changing to /SpliceCom/ftp/tftp/<br/>Backing up PCS Site Files<br/>");
			exec("cd /SpliceCom/ftp/tftp/; nice -10 tar -cvf /SpliceCom/Web/download/site-pcs5xx.tar *.site;");
			show("Moving files and compressing<br/>");
			exec("cd /SpliceCom/Web/download/; nice -10 tar -cvf $backup site-pcs5xx.tar; rm site-pcs5xx.tar;");
	}
	

if (file_exists("/SpliceCom/Web/download/$backup")) {
stop("<b>Done</b>...<br/><br/><a href='download.php?download=/SpliceCom/Web/download/$backup'><img src='images/down.png' alt='Download Backup' title='Download Backup' width='50' height='50'><br/>Download</a>");
} else {
stop("<b>Done</b>...<br/><br/>No Backup file Created. Check The Items Exist On The CallServer / SoftPBX");
	}
}




function start(){
echo "<div><script type=\"text/javascript\">var bar2= createBar(320,15,'white',1,'black','orange',85,7,3,'');</script></div>";
}

function show($str){
echo $str."<br/>";
echo "<script type=\"text/javascript\">bar2.togglePause()</script>";
@ob_flush(); @flush();
}

function stop($str){
echo $str."<br/>";
echo "<script type=\"text/javascript\">bar2.hideBar()</script>";
@ob_flush(); @flush();
}


?>
</div></body></html>
